# debiantospdx

[![Apache2.0 License](https://img.shields.io/badge/License-Apatch2.0-green.svg?style=for-the-badge)](https://choosealicense.com/licenses/apache-2.0/)

システムに存在するすべてのDebianパッケージのSPDXファイルを生成するコマンドラインツール

パッケージ名・バージョン・ソフトウェアライセンス・コピーライト・パッケージ間の依存関係の解析を行う

## Usage/Examples

```bash
teplate 1 3 5 -c 22 --both
```

## Authors

- [@tk-tanab](https://github.com/tk-tanab)


## License

- [Apatch2.0](https://choosealicense.com/licenses/apache-2.0/)

